@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QDialogButtonBox>
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
+#include <QPushButton>
 #include <QRect>
 #include <QDebug>
 
@@ -424,10 +425,16 @@ void CropTool::keyPressEvent(QKeyEvent* event)
         buttons->rejected();
         break;
     case Qt::Key_Return:
-    case Qt::Key_Enter:
+    case Qt::Key_Enter: {
         event->accept();
-        buttons->accepted();
+        auto focusButton = static_cast<QPushButton*>(buttons->focusWidget());
+        if (focusButton && buttons->buttonRole(focusButton) == QDialogButtonBox::RejectRole) {
+            buttons->rejected();
+        } else {
+            buttons->accepted();
+        }
         break;
+    }
     default:
         break;
     }
