@@ -47,18 +47,28 @@ public:
 
     void setAdvancedSettingsEnabled(bool enable);
     bool advancedSettingsEnabled() const;
+    void setPreserveAspectRatio(bool preserve);
+    bool preserveAspectRatio() const;
+    void setCropRatio(QSizeF size);
+    int cropRatioIndex() const;
+    void setCropRatioIndex(int index);
+    QSizeF cropRatio() const;
 
 Q_SIGNALS:
     void cropRequested();
     void done();
 
+public Q_SLOTS:
+    void updateCropRatio();
+
 private Q_SLOTS:
     void slotPositionChanged();
     void slotWidthChanged();
     void slotHeightChanged();
     void setCropRect(const QRect& rect);
 
-    void slotRatioComboBoxEditTextChanged();
+    void slotAdvancedCheckBoxToggled(bool checked);
+    void slotRatioComboBoxChanged();
     void applyRatioConstraint();
 
 private:
