@@ -43,11 +43,11 @@ class LoadingDocumentImpl : public AbstractDocumentImpl
     Q_OBJECT
 public:
     LoadingDocumentImpl(Document*);
-    ~LoadingDocumentImpl();
+    ~LoadingDocumentImpl() Q_DECL_OVERRIDE;
 
-    virtual void init() Q_DECL_OVERRIDE;
-    virtual Document::LoadingState loadingState() const Q_DECL_OVERRIDE;
-    virtual bool isEditable() const Q_DECL_OVERRIDE;
+    void init() Q_DECL_OVERRIDE;
+    Document::LoadingState loadingState() const Q_DECL_OVERRIDE;
+    bool isEditable() const Q_DECL_OVERRIDE;
 
     void loadImage(int invertedZoom);
 
