@@ -405,7 +405,7 @@ struct DocumentViewPrivate
         }
         mDrag = new QDrag(q);
         const auto itemList = KFileItemList({q->document()->url()});
-        mDrag->setMimeData(MimeTypeUtils::selectionMimeData(itemList));
+        mDrag->setMimeData(MimeTypeUtils::selectionMimeData(itemList, MimeTypeUtils::DropTarget));
 
         if (q->document()->isModified()) {
             setDragPixmap(QPixmap::fromImage(q->document()->image()));
@@ -464,6 +464,10 @@ DocumentView::DocumentView(QGraphicsScene* scene)
     d->setCurrentAdapter(new EmptyAdapter);
 
     setAcceptDrops(true);
+
+    connect(DocumentFactory::instance(), &DocumentFactory::documentChanged, this, [this]() {
+        d->updateCaption();
+    });
 }
 
 DocumentView::~DocumentView()
