@@ -18,6 +18,17 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 
 */
+
+/*
+   *****************************************************
+   ******************************************************
+   **** NOTE: This class is deprecated. Do not use it. **
+   ****   It will be removed in the QT 6 timeframe.    **
+   ******************************************************
+   ******************************************************
+*/
+
+
 #ifndef CONTEXTBARBUTTON_H
 #define CONTEXTBARBUTTON_H
 
@@ -39,8 +50,8 @@ class ContextBarButton : public QToolButton
 {
     Q_OBJECT
 public:
-    explicit ContextBarButton(const QString& iconName, QWidget* parent = 0);
-    ~ContextBarButton();
+    explicit ContextBarButton(const QString& iconName, QWidget* parent = nullptr);
+    ~ContextBarButton() Q_DECL_OVERRIDE;
 
 protected:
     void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
