@@ -68,8 +68,8 @@ ZoomSlider::ZoomSlider(QWidget* parent)
 {
     d->mZoomInButton = createZoomButton("zoom-in");
     d->mZoomOutButton = createZoomButton("zoom-out");
-    d->mZoomInAction = 0;
-    d->mZoomOutAction = 0;
+    d->mZoomInAction = nullptr;
+    d->mZoomOutAction = nullptr;
 
     d->mSlider = new QSlider;
     d->mSlider->setOrientation(Qt::Horizontal);
