@@ -60,12 +60,12 @@ struct ZoomWidgetPrivate
 
     StatusBarToolButton* mZoomToFitButton;
     StatusBarToolButton* mActualSizeButton;
-    StatusBarToolButton* mZoomToFitWidthButton;
+    StatusBarToolButton* mZoomToFillButton;
     QLabel* mZoomLabel;
     ZoomSlider* mZoomSlider;
     QAction* mZoomToFitAction;
     QAction* mActualSizeAction;
-    QAction* mZoomToFitWidthAction;
+    QAction* mZoomToFillAction;
 
     bool mZoomUpdatedBySlider;
 
@@ -92,19 +92,19 @@ ZoomWidget::ZoomWidget(QWidget* parent)
 
     d->mZoomToFitButton = new StatusBarToolButton;
     d->mActualSizeButton = new StatusBarToolButton;
-    d->mZoomToFitWidthButton = new StatusBarToolButton;
+    d->mZoomToFillButton = new StatusBarToolButton;
     d->mZoomToFitButton->setCheckable(true);
     d->mActualSizeButton->setCheckable(true);
-    d->mZoomToFitWidthButton->setCheckable(true);
+    d->mZoomToFillButton->setCheckable(true);
     d->mZoomToFitButton->setChecked(true);
 
     if (QApplication::isLeftToRight()) {
         d->mZoomToFitButton->setGroupPosition(StatusBarToolButton::GroupLeft);
-        d->mZoomToFitWidthButton->setGroupPosition(StatusBarToolButton::GroupCenter);
+        d->mZoomToFillButton->setGroupPosition(StatusBarToolButton::GroupCenter);
         d->mActualSizeButton->setGroupPosition(StatusBarToolButton::GroupRight);
     } else {
         d->mActualSizeButton->setGroupPosition(StatusBarToolButton::GroupLeft);
-        d->mZoomToFitWidthButton->setGroupPosition(StatusBarToolButton::GroupCenter);
+        d->mZoomToFillButton->setGroupPosition(StatusBarToolButton::GroupCenter);
         d->mZoomToFitButton->setGroupPosition(StatusBarToolButton::GroupRight);
     }
 
@@ -123,7 +123,7 @@ ZoomWidget::ZoomWidget(QWidget* parent)
     layout->setMargin(0);
     layout->setSpacing(0);
     layout->addWidget(d->mZoomToFitButton);
-    layout->addWidget(d->mZoomToFitWidthButton);
+    layout->addWidget(d->mZoomToFillButton);
     layout->addWidget(d->mActualSizeButton);
     layout->addWidget(d->mZoomSlider);
     layout->addWidget(d->mZoomLabel);
@@ -134,29 +134,30 @@ ZoomWidget::~ZoomWidget()
     delete d;
 }
 
-void ZoomWidget::setActions(QAction* zoomToFitAction, QAction* actualSizeAction, QAction* zoomInAction, QAction* zoomOutAction, QAction* zoomToFitWidthAction)
+void ZoomWidget::setActions(QAction* zoomToFitAction, QAction* actualSizeAction, QAction* zoomInAction, QAction* zoomOutAction, QAction* zoomToFillAction)
 {
     d->mZoomToFitAction = zoomToFitAction;
     d->mActualSizeAction = actualSizeAction;
-    d->mZoomToFitWidthAction = zoomToFitWidthAction;
+    d->mZoomToFillAction = zoomToFillAction;
 
     d->mZoomToFitButton->setDefaultAction(zoomToFitAction);
     d->mActualSizeButton->setDefaultAction(actualSizeAction);
-    d->mZoomToFitWidthButton->setDefaultAction(zoomToFitWidthAction);
+    d->mZoomToFillButton->setDefaultAction(zoomToFillAction);
 
     d->mZoomSlider->setZoomInAction(zoomInAction);
     d->mZoomSlider->setZoomOutAction(zoomOutAction);
 
     QActionGroup *actionGroup = new QActionGroup(d->q);
     actionGroup->addAction(d->mZoomToFitAction);
-    actionGroup->addAction(d->mZoomToFitWidthAction);
+    actionGroup->addAction(d->mZoomToFillAction);
     actionGroup->addAction(d->mActualSizeAction);
     actionGroup->setExclusive(true);
 
     // Adjust sizes
-    int width = qMax(d->mZoomToFitButton->sizeHint().width(), d->mActualSizeButton->sizeHint().width());
+    int width = std::max({d->mZoomToFitButton->sizeHint().width(), d->mActualSizeButton->sizeHint().width(), d->mZoomToFillButton->sizeHint().width()});
     d->mZoomToFitButton->setFixedWidth(width);
     d->mActualSizeButton->setFixedWidth(width);
+    d->mZoomToFillButton->setFixedWidth(width);
 }
 
 void ZoomWidget::slotZoomSliderActionTriggered()
