@@ -40,7 +40,7 @@ class GWENVIEWLIB_EXPORT ZoomWidget : public QFrame
 {
     Q_OBJECT
 public:
-    ZoomWidget(QWidget* parent = 0);
+    explicit ZoomWidget(QWidget* parent = nullptr);
     ~ZoomWidget();
 
     void setActions(QAction* zoomToFitAction, QAction* actualSizeAction, QAction* zoomInAction, QAction* zoomOutAction, QAction* zoomToFillAction);
